@@ -310,6 +310,8 @@ void PinyinEngine::initPredict(InputContext *inputContext) {
     if (auto candidateList = predictCandidateList(words)) {
         auto &inputPanel = inputContext->inputPanel();
         inputPanel.setCandidateList(std::move(candidateList));
+    } else {
+        state->predictWords_.clear();
     }
     inputContext->updatePreedit();
     inputContext->updateUserInterface(UserInterfaceComponent::InputPanel);
@@ -735,7 +737,9 @@ PinyinEngine::PinyinEngine(Instance *instance)
         numpadSelectionKeys_.emplace_back(sym, numpadStates);
     }
 
-    predictionAction_.setShortText(_("Prediction"));
+    predictionAction_.setShortText(*config_.predictionEnabled
+                                       ? _("Prediction Enabled")
+                                       : _("Prediction Disabled"));
     predictionAction_.setLongText(_("Show prediction words"));
     predictionAction_.setIcon(*config_.predictionEnabled
                                   ? "fcitx-remind-active"
@@ -743,6 +747,9 @@ PinyinEngine::PinyinEngine(Instance *instance)
     predictionAction_.connect<SimpleAction::Activated>(
         [this](InputContext *ic) {
             config_.predictionEnabled.setValue(!(*config_.predictionEnabled));
+            predictionAction_.setShortText(*config_.predictionEnabled
+                                               ? _("Prediction Enabled")
+                                               : _("Prediction Disabled"));
             predictionAction_.setIcon(*config_.predictionEnabled
                                           ? "fcitx-remind-active"
                                           : "fcitx-remind-inactive");
@@ -762,12 +769,20 @@ PinyinEngine::PinyinEngine(Instance *instance)
             handle2nd3rdSelection(keyEvent);
         });
 
+    pyConfig_.shuangpinProfile.annotation().setHidden(true);
+    pyConfig_.showShuangpinMode.annotation().setHidden(true);
+    pyConfig_.fuzzyConfig->partialSp.annotation().setHidden(true);
+
     checkCloudPinyinAvailable_ =
         instance_->eventLoop().addDeferEvent([this](EventSource *) {
             bool hasCloudPinyin = cloudpinyin() != nullptr;
-            config_.cloudPinyinEnabled.annotation().setHidden(!hasCloudPinyin);
-            config_.cloudPinyinIndex.annotation().setHidden(!hasCloudPinyin);
-            config_.cloudpinyin.setHidden(!hasCloudPinyin);
+            for (auto *configPtr : {&config_, &pyConfig_}) {
+                configPtr->cloudPinyinEnabled.annotation().setHidden(
+                    !hasCloudPinyin);
+                configPtr->cloudPinyinIndex.annotation().setHidden(
+                    !hasCloudPinyin);
+                configPtr->cloudpinyin.setHidden(!hasCloudPinyin);
+            }
             checkCloudPinyinAvailable_.reset();
             return true;
         });
@@ -1004,6 +1019,8 @@ void PinyinEngine::populateConfig() {
                            *config_.extBEnabled
                                ? libime::PinyinDictFlag::NoFlag
                                : libime::PinyinDictFlag::Disabled);
+
+    pyConfig_ = config_;
 }
 
 void PinyinEngine::reloadConfig() {
@@ -1845,6 +1862,17 @@ std::string PinyinEngine::subMode(const InputMethodEntry &entry,
     return {};
 }
 
+const Configuration *PinyinEngine::getConfig() const { return &config_; }
+
+const Configuration *
+PinyinEngine::getConfigForInputMethod(const InputMethodEntry &entry) const {
+    // Hide shuangpin options.
+    if (entry.uniqueName() == "pinyin") {
+        return &pyConfig_;
+    }
+    return &config_;
+}
+
 void PinyinEngine::invokeActionImpl(const InputMethodEntry &entry,
                                     InvokeActionEvent &event) {
     auto inputContext = event.inputContext();
